Learn R Programming

flexurba (version 0.2.3)

load_proxies_belgium: Load the data for three urban proxies for Belgium

Description

The function loads example population, built-up area and night-time light data for Belgium. It is based on the global datasets provided in the accompanying flexurbaData package.

# POPULATION DATA
terra::rast(system.file("proxies/processed-ghs-pop.tif", package = "flexurbaData")) %>%
   terra::crop(terra::ext(187000, 490000, 5816000, 6035000)) %>%
   terra::writeRaster('inst/extdata/belgium/processed-ghs-pop-belgium.tif')

# BUILT-UP AREA DATA terra::rast(system.file("proxies/processed-ghs-built-s.tif", package = "flexurbaData")) %>% terra::crop(terra::ext(187000, 490000, 5816000, 6035000)) %>% terra::writeRaster('inst/extdata/belgium/processed-ghs-built-s-belgium.tif')

# LIGHT DATA terra::rast(system.file("proxies/processed-viirs-light.tif", package = "flexurbaData")) %>% terra::crop(terra::ext(187000, 490000, 5816000, 6035000)) %>% terra::writeRaster('inst/extdata/belgium/processed-viirs-light-belgium.tif')

The data are processed versions of the population and built-up grid from the Global Human Settlement Layer and the night-time light grid from the Earth Observation Group. See the flexurbaData package for more information of how these raw data produced were processed.

Usage

load_proxies_belgium()

Arguments

Value

named list with gridded population, built-up area and night-time light data for Belgium.

Examples

Run this code
load_proxies_belgium()

Run the code above in your browser using DataLab